@@ -56,9 +56,11 @@ class FileInterface():
     def grab_proper(self):
 
         if(os.path.exists(self.path)): return None
-        with open(self.path ,'r') as f: 
-            try:    v = self.recover(json.loads(f.read() or ""))
-            except: v = None
+        with open(self.path ,'r') as f:
+            cc = json.loads(f.read() or "") 
+            
+        try   : v = self.recover(cc)
+        except: v = None
 
         return v
 
